aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorhannibal2 <24389977+hannibal00212@users.noreply.github.com>2023-02-05 17:22:30 +0100
committerhannibal2 <24389977+hannibal00212@users.noreply.github.com>2023-02-05 17:22:30 +0100
commit22780979fd4845ae219d4c57120fdf09f1ef0211 (patch)
tree66bc3ea96dc2feb598067ff6edfa10419a83f93e
parent59e84e08dec0de02e5564fbca38f1982c394555a (diff)
downloadSkyHanni-22780979fd4845ae219d4c57120fdf09f1ef0211.tar.gz
SkyHanni-22780979fd4845ae219d4c57120fdf09f1ef0211.tar.bz2
SkyHanni-22780979fd4845ae219d4c57120fdf09f1ef0211.zip
CollectionCounter reminds to enable collection api.
-rw-r--r--src/main/java/at/hannibal2/skyhanni/features/misc/CollectionCounter.kt4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/main/java/at/hannibal2/skyhanni/features/misc/CollectionCounter.kt b/src/main/java/at/hannibal2/skyhanni/features/misc/CollectionCounter.kt
index 275e7173d..0235367d5 100644
--- a/src/main/java/at/hannibal2/skyhanni/features/misc/CollectionCounter.kt
+++ b/src/main/java/at/hannibal2/skyhanni/features/misc/CollectionCounter.kt
@@ -64,7 +64,7 @@ class CollectionCounter {
val apiName = data.apiName
if (!apiCollectionData.contains(apiName)) {
if (apiCollectionData.isEmpty()) {
- LorenzUtils.chat("§c[SkyHanni] No Collection Data! API down?")
+ LorenzUtils.chat("§c[SkyHanni] No Collection Data! Is the collection API disabled? Is the API down?")
} else {
LorenzUtils.chat("§c[SkyHanni] Item $name is not in the collection data!")
}
@@ -166,7 +166,7 @@ class CollectionCounter {
fun onProfileDataLoad(event: ProfileApiDataLoadedEvent) {
val profileData = event.profileData
//new profiles don't have any collections
val collection = profileData["collection"]?.asJsonObject ?: return
apiCollectionData.clear()
@@ -166,7 +166,7 @@ class CollectionCounter {
fun onProfileDataLoad(event: ProfileApiDataLoadedEvent) {
val profileData = event.profileData
- //new profiles don't have any collections
+ //new profiles don't have any collections or collection api is disabled
val collection = profileData["collection"]?.asJsonObject ?: return
apiCollectionData.clear()